@@ -304,13 +304,8 @@ int ecs_TileGetLine(s,t,start,end)
   /* scan the first line of the buffer for uninitialized pixels. */
   for (count=0; count< t->linelength; count++) {
     if (t->linebuffer->linebuffer[count]==t->uninitializedValue) {
-      if (s->rasterconversion.isProjEqual) {
 	i=y;
 	j=count;
-      } else {
-	i = ECSGETI(s,((double) y),((double) count));
-	j = ECSGETJ(s,((double) y),((double) count));
-      }
       
       if (t->tileDimCallback!=NULL) {
 	coord.x=s->currentRegion.west+(j+0.5)*s->currentRegion.ew_res;    
@@ -489,18 +484,9 @@ int ecs_TileFill(ecs_Server *s, ecs_TileStructure *t, int index, ecs_TileID *cur
 
   for (count=tbuf->last+1; count< t->linelength; count++) {
     if (tbuf->linebuffer[count]==t->uninitializedValue) {
-      
-      if (s->rasterconversion.isProjEqual) {
-	
+
 	j = count;
 	i = bufptr;
-	
-      } else { /* if s->rasterconversion */
-	
-	i = ECSGETI(s,((double) bufptr),((double) count));
-	j = ECSGETJ(s,((double) bufptr),((double) count));
-	
-      }
 
       if (t->tileDimCallback!=NULL) {
 	coord.x=s->currentRegion.west+j*s->currentRegion.ew_res;    
